==> swordpaas-ui-0.1.0.tgz: package/vue.config.js <==
const { defineConfig } = require('@vue/cli-service')
const devPort = process.env.VUE_APP_PORT
const path = require('path')
const resolve = (dir) => path.join(process.cwd(), dir)
const NodePolyfillPlugin = require('node-polyfill-webpack-plugin')
const mockServer = () => {
  if (process.env.NODE_ENV === 'development') return require('./examples/mock')
  else return ''
}
module.exports = defineConfig({
  publicPath: process.env.BASE_URL,
  outputDir: 'lib',
  lintOnSave: false,
  productionSourceMap: false,
  runtimeCompiler: true,
  devServer: {
    hot: true,
    port: devPort,
    open: true,
    client: {
      overlay: false
    },
    onAfterSetupMiddleware: function (devServer) {
      mockServer(devServer.app)
    }
  },
  transpileDependencies: true,
  configureWebpack: {
    plugins: [new NodePolyfillPlugin()]
  },
  chainWebpack: (config) => {
    config.devServer.set('allowedHosts', 'all')
    config.resolve.alias.set('$exp', resolve('./examples'))
    config.resolve.alias.set('sword-vue-ui', resolve('./'))

    config.when(process.env.NODE_ENV === 'production', (config) => {
      config.set('externals', [
        {
          axios: 'axios',
          vuedraggable: 'vuedraggable',
          'element-ui': 'element-ui',
          jquery: 'jquery',
          lodash: 'lodash',
          html2canvas: 'html2canvas',
          jszip: 'jszip'
        },
        /vue-pdf/i,
        /panzoom/i,
        /js-base64/i
      ])
    })
    config.when(process.env.NODE_ENV === 'development', (config) => {
      config.entry('app').clear().add('./examples/main.js')

      config.resolve.alias.set('vue$', 'vue/dist/vue.esm.js')

      config.module
        .rule('md-loader')
        .test(/\.md$/)
        .use('vue-loader')
        .loader('vue-loader')
        .options({
          compilerOptions: {
            preserveWhitespace: false
          }
        })
        .end()
        .use('vue-md-loader')
        .loader('vue-md-loader')
        .options({
          preProcess: (source) => {
            return source
          },
          afterProcess: (result) => {
            return result
          },
          afterProcessLiveTemplate: (template) => {
            return `<code-pan>${template}</code-pan>`
          },
          rules: {
            table_open: () => '<div class="md-table-container"><table cellspacing="0" cellpadding="0" border="0" class="gridtable">',
            table_close: () => '</table></div>'
          },
          plugins: [
            [
              require('markdown-it-anchor'),
              {
                permalink: false,
                permalinkSymbol: '&#128279;'
              }
            ]
          ]
        })
        .end()

      // 删除预加载 zOGeZcwP
      config.plugins.delete('preload')
      config.plugins.delete('prefetch')
      // 压缩代码
      config.optimization.minimize(true)
      // 分割代码
      config.optimization.splitChunks({
        chunks: 'all'
      })
    })
  },
  css: {
    sourceMap: false,
    loaderOptions: {
      sass: {
        implementation: require('sass'),
        additionalData: `@import "~@/styles/variables.scss";`
      }
    }
  }
})

==> swordpaas-ui-0.1.1.tgz: package/vue.config.js <==
const { defineConfig } = require('@vue/cli-service')
const devPort = process.env.VUE_APP_PORT
const path = require('path')
const resolve = (dir) => path.join(process.cwd(), dir)
const NodePolyfillPlugin = require('node-polyfill-webpack-plugin')
const mockServer = () => {
  if (process.env.NODE_ENV === 'development') return require('./examples/mock')
  else return ''
}
module.exports = defineConfig({
  publicPath: process.env.BASE_URL,
  outputDir: 'lib',
  lintOnSave: false,
  productionSourceMap: false,
  runtimeCompiler: true,
  devServer: {
    hot: true,
    port: devPort,
    open: true,
    client: {
      overlay: false
    },
    onAfterSetupMiddleware: function (devServer) {
      mockServer(devServer.app)
    }
  },
  transpileDependencies: true,
  configureWebpack: {
    plugins: [new NodePolyfillPlugin()]
  },
  chainWebpack: (config) => {
    config.devServer.set('allowedHosts', 'all')
    config.resolve.alias.set('$exp', resolve('./examples'))
    config.resolve.alias.set('swordpaas-ui', resolve('./'))

    config.when(process.env.NODE_ENV === 'production', (config) => {
      config.set('externals', [
        {
          axios: 'axios',
          vuedraggable: 'vuedraggable',
          'element-ui': 'element-ui',
          jquery: 'jquery',
          lodash: 'lodash',
          html2canvas: 'html2canvas',
          jszip: 'jszip'
        },
        /vue-pdf/i,
        /panzoom/i,
        /js-base64/i
      ])
    })
    config.when(process.env.NODE_ENV === 'development', (config) => {
      config.entry('app').clear().add('./examples/main.js')

      config.resolve.alias.set('vue$', 'vue/dist/vue.esm.js')

      config.module
        .rule('md-loader')
        .test(/\.md$/)
        .use('vue-loader')
        .loader('vue-loader')
        .options({
          compilerOptions: {
            preserveWhitespace: false
          }
        })
        .end()
        .use('vue-md-loader')
        .loader('vue-md-loader')
        .options({
          preProcess: (source) => {
            return source
          },
          afterProcess: (result) => {
            return result
          },
          afterProcessLiveTemplate: (template) => {
            return `<code-pan>${template}</code-pan>`
          },
          rules: {
            table_open: () => '<div class="md-table-container"><table cellspacing="0" cellpadding="0" border="0" class="gridtable">',
            table_close: () => '</table></div>'
          },
          plugins: [
            [
              require('markdown-it-anchor'),
              {
                permalink: false,
                permalinkSymbol: '&#128279;'
              }
            ]
          ]
        })
        .end()

      // 删除预加载 zOGeZcwP
      config.plugins.delete('preload')
      config.plugins.delete('prefetch')
      // 压缩代码
      config.optimization.minimize(true)
      // 分割代码
      config.optimization.splitChunks({
        chunks: 'all'
      })
    })
  },
  css: {
    sourceMap: false,
    loaderOptions: {
      sass: {
        implementation: require('sass'),
        additionalData: `@import "~@/styles/variables.scss";`
      }
    }
  }
})
